@@ -26,9 +26,11 @@ class FilesFilterList(BaseModel):
     blacklist: Optional[List[FileType]] = []
     whitelist: Optional[List[FileType]] = []
 
+
 class TextFilter(FilterList):
     case_sensitive: Optional[bool] = False
 
+
 class Filters(BaseModel):
     users: Optional[FilterList] = FilterList()
     files: Optional[FilesFilterList] = FilesFilterList()
@@ -36,7 +38,7 @@ class Filters(BaseModel):
 
 
 class TgcfFilter:
-    id = "filter"
+    id_ = "filter"
 
     def __init__(self, data):
         print("tgcf filter data loaded")
@@ -45,7 +47,7 @@ class TgcfFilter:
         logging.info(self.filters)
 
     def case_correct(self):
-        textf:TextFilter = self.filters.text
+        textf: TextFilter = self.filters.text
 
         if textf.case_sensitive is False:
             textf.blacklist = [item.lower() for item in textf.blacklist]
@@ -61,14 +63,12 @@ class TgcfFilter:
     def text_safe(self, message):
         flist = self.filters.text
 
-
         text = message.text
         if not flist.case_sensitive:
             text = text.lower()
         if not text and flist.whitelist == []:
             return True
 
-
         for forbidden in flist.blacklist:
             if forbidden in text:
                 return False
