@@ -3,7 +3,7 @@
 import yaml
 from telethon import events
 
-from tgcf import config, const
+from tgcf import config, const, plugins
 from tgcf.bot.utils import admin_protect, display_forwards, get_args, remove_source
 
 
@@ -27,12 +27,17 @@ async def forward_command_handler(event):
     try:
         args = get_args(event.message.text)
         if not args:
-            raise ValueError(f"{notes}\n{display_forwards(config.CONFIG.forwards)}")
+            raise ValueError(
+                f"{notes}\n{display_forwards(config.CONFIG.forwards)}")
 
         parsed_args = yaml.safe_load(args)
         print(parsed_args)
         forward = config.Forward(**parsed_args)
         print(forward)
+        try:
+            remove_source(forward.source, config.CONFIG.forwards)
+        except:
+            pass
         config.CONFIG.forwards.append(forward)
         config.from_to = config.load_from_to(config.CONFIG.forwards)
 
@@ -61,13 +66,15 @@ async def remove_command_handler(event):
     try:
         args = get_args(event.message.text)
         if not args:
-            raise ValueError(f"{notes}\n{display_forwards(config.CONFIG.forwards)}")
+            raise ValueError(
+                f"{notes}\n{display_forwards(config.CONFIG.forwards)}")
 
         parsed_args = yaml.safe_load(args)
         print(parsed_args)
         source_to_remove = parsed_args.get("source")
         print(source_to_remove)
-        config.CONFIG.forwards = remove_source(source_to_remove, config.CONFIG.forwards)
+        config.CONFIG.forwards = remove_source(
+            source_to_remove, config.CONFIG.forwards)
         print(config.CONFIG.forwards)
         config.from_to = config.load_from_to(config.CONFIG.forwards)
 
@@ -81,6 +88,35 @@ async def remove_command_handler(event):
         raise events.StopPropagation
 
 
+@admin_protect
+async def style_command_handler(event):
+    """Handle the /style command"""
+    notes = """This command is used to set the style of the messages to be forwarded.
+
+    Example: `/style bold`
+
+    Options are preserve,normal,bold,italics,code, strike
+
+    """.replace("    ", "")
+
+    try:
+        args = get_args(event.message.text)
+        if not args:
+            raise ValueError(
+                f"{notes}\n")
+        config.CONFIG.plugins.update({"format": {"style": args}})
+        config.update_config_file(config.CONFIG)
+        plugins.plugins = plugins.load_plugins()
+        await event.respond("Success")
+
+    except ValueError as err:
+        print(err)
+        await event.respond(str(err))
+
+    finally:
+        raise events.StopPropagation
+
+
 async def start_command_handler(event):
     """Handle the /start command."""
     await event.respond(const.BotMessages.start)
@@ -89,3 +125,12 @@ async def start_command_handler(event):
 async def help_command_handler(event):
     """Handle the /help command."""
     await event.respond(const.BotMessages.bot_help)
+
+
+BOT_EVENTS = {
+    "bot_start": (start_command_handler, events.NewMessage(pattern="/start")),
+    "bot_forward": (forward_command_handler, events.NewMessage(pattern="/forward")),
+    "bot_remove": (remove_command_handler, events.NewMessage(pattern="/remove")),
+    "bot_style": (style_command_handler, events.NewMessage(pattern="/style")),
+    "bot_help": (help_command_handler, events.NewMessage(pattern="/help")),
+}
