@@ -4,13 +4,8 @@ import logging
 from telethon import events
 
 from tgcf import config, const
-from tgcf.bot import (
-    forward_command_handler,
-    help_command_handler,
-    remove_command_handler,
-    start_command_handler,
-)
-from tgcf.plugins import apply_plugins
+from tgcf.bot import BOT_EVENTS
+from tgcf.plugins import apply_plugins, plugins
 from tgcf.utils import send_message
 
 existing_hashes = []
@@ -97,7 +92,7 @@ async def edited_message_handler(event):
 
     if fwded_msgs:
         for msg in fwded_msgs:
-            if config.CONFIG.live.delete_on_edit == message.text:
+            if config.CONFIG.live.delete_on_edit == message.raw_text:
                 await msg.delete()
                 await message.delete()
             else:
@@ -127,19 +122,25 @@ async def deleted_message_handler(event):
 
 
 ALL_EVENTS = {
-    "bot_start": (start_command_handler, events.NewMessage(pattern="/start")),
-    "bot_forward": (forward_command_handler, events.NewMessage(pattern="/forward")),
-    "bot_remove": (remove_command_handler, events.NewMessage(pattern="/remove")),
-    "bot_help": (help_command_handler, events.NewMessage(pattern="/help")),
     "new": (new_message_handler, events.NewMessage()),
     "edited": (edited_message_handler, events.MessageEdited()),
     "deleted": (deleted_message_handler, events.MessageDeleted()),
 }
 
+ALL_EVENTS.update(BOT_EVENTS)
+
+for _, plugin in plugins.items():
+    try:
+        event_handlers = getattr(plugin, "event_handlers")
+        if event_handlers:
+            ALL_EVENTS.update(event_handlers)
+    except AttributeError:
+        pass
+
 
 def start_sync():
     """Start tgcf live sync."""
-    # pylint: disable= import-outside-toplevel
+    # pylint: disable=import-outside-toplevel
     from telethon.sync import TelegramClient, functions, types
 
     client = TelegramClient(config.SESSION, config.API_ID, config.API_HASH)
